@@ -1,4 +1,4 @@
-#' Interpret Odds ratio
+#' Interpret Odds Ratio
 #'
 #' @param OR Value or vector of (log) odds ratio values.
 #' @param rules Can be "`chen2010"` (default), `"cohen1988"` (through
@@ -32,24 +32,25 @@
 #'
 #' - Chen, H., Cohen, P., & Chen, S. (2010). How big is a big odds ratio?
 #' Interpreting the magnitudes of odds ratios in epidemiological studies.
-#' Communications in Statistics—Simulation and Computation, 39(4), 860-864.
+#' Communications in Statistics-Simulation and Computation, 39(4), 860-864.
 #'
 #' - Sánchez-Meca, J., Marín-Martínez, F., & Chacón-Moscoso, S. (2003).
 #' Effect-size indices for dichotomized outcomes in meta-analysis. Psychological
 #' methods, 8(4), 448.
 #'
+#' @keywords interpreters
 #' @export
 interpret_oddsratio <- function(OR, rules = "chen2010", log = FALSE, ...) {
   if (log) {
-    OR <- exp(abs(OR))
+    f_transform <- function(.x) exp(abs(.x))
   } else {
-    OR <- exp(abs(log(OR)))
+    f_transform <- function(.x) exp(abs(log(.x)))
   }
 
 
   if (is.character(rules) && rules == "cohen1988") {
-    d <- oddsratio_to_d(OR, log = FALSE)
-    return(interpret_cohens_d(abs(d), rules = rules))
+    d <- oddsratio_to_d(OR, log = log)
+    return(interpret_cohens_d(d, rules = rules))
   }
 
   rules <- .match.rules(
@@ -62,5 +63,5 @@ interpret_oddsratio <- function(OR, rules = "chen2010", log = FALSE, ...) {
     )
   )
 
-  interpret(OR, rules)
+  interpret(OR, rules, transform = f_transform)
 }
